@@ -30,17 +30,17 @@ from pyams_form.interfaces.form import IAJAXFormRenderer, IDataExtractedEvent
 from pyams_layer.interfaces import IPyAMSLayer
 from pyams_pagelet.pagelet import pagelet_config
 from pyams_security.interfaces import ILocalUser, ISecurityManager, IUsersFolderPlugin, \
-    IViewContextPermissionChecker
+    IViewContextPermissionChecker, USERS_FOLDER_PLUGIN_LABEL
 from pyams_security.interfaces.base import MANAGE_SECURITY_PERMISSION
 from pyams_security_views.zmi import SecurityPluginsTable
-from pyams_security_views.zmi.plugin import SecurityPluginAddForm, SecurityPluginAddMenu, \
-    SecurityPluginPropertiesEditForm
-from pyams_site.interfaces import ISiteRoot
+from pyams_security_views.zmi.plugin import InnerSecurityPluginFormMixin, SecurityPluginAddForm, \
+    SecurityPluginAddMenu, SecurityPluginPropertiesEditForm
 from pyams_skin.schema.button import ActionButton, SubmitButton
-from pyams_skin.viewlet.actions import ContextAction
+from pyams_skin.viewlet.actions import ContextAddAction
 from pyams_table.column import GetAttrColumn
 from pyams_table.interfaces import IColumn, IValues
 from pyams_utils.adapter import ContextAdapter, ContextRequestViewAdapter, adapter_config
+from pyams_utils.registry import get_utility
 from pyams_utils.timezone import tztime
 from pyams_utils.traversing import get_parent
 from pyams_utils.url import absolute_url
@@ -62,13 +62,13 @@ from pyams_security_views import _  # pylint: disable=ungrouped-imports
 
 
 @viewlet_config(name='add-users-folder-plugin.menu',
-                context=ISiteRoot, layer=IAdminLayer, view=SecurityPluginsTable,
-                manager=IContextAddingsViewletManager, weight=40,
+                context=ISecurityManager, layer=IAdminLayer, view=SecurityPluginsTable,
+                manager=IContextAddingsViewletManager, weight=20,
                 permission=MANAGE_SECURITY_PERMISSION)
 class UsersFolderPluginAddMenu(SecurityPluginAddMenu):
     """Users folder plug-in add menu"""
 
-    label = _("Add users folder...")
+    label = _("Add local users folder...")
     href = 'add-users-folder-plugin.html'
 
 
@@ -78,15 +78,15 @@ class UsersFolderPluginAddMenu(SecurityPluginAddMenu):
 class UsersFolderPluginAddForm(SecurityPluginAddForm):
     """Users folder plug-in add form"""
 
-    legend = _("Add users folder plug-in")
     content_factory = IUsersFolderPlugin
+    content_label = USERS_FOLDER_PLUGIN_LABEL
 
 
-@ajax_form_config(name='properties.html', context=IUsersFolderPlugin, layer=IPyAMSLayer)
+@ajax_form_config(name='properties.html',
+                  context=IUsersFolderPlugin, layer=IPyAMSLayer)
 class UsersFolderPropertiesEditForm(SecurityPluginPropertiesEditForm):
     """Users folder plug-in properties edit form"""
 
-    title = _("Users folder plug-in")
     plugin_interface = IUsersFolderPlugin
 
 
@@ -102,7 +102,8 @@ class LocalUsersSearchForm(SearchForm):  # pylint: disable=abstract-method
     @property
     def back_url(self):
         """Form back URL getter"""
-        return absolute_url(self.request.root, self.request, 'security-plugins.html')
+        manager = get_utility(ISecurityManager)
+        return absolute_url(manager, self.request, 'security-plugins.html')
 
 
 @pagelet_config(name='search.html', context=IUsersFolderPlugin, layer=IPyAMSLayer,
@@ -231,27 +232,18 @@ def delete_local_user(request):
 @viewlet_config(name='add-user.action', context=IUsersFolderPlugin, layer=IAdminLayer,
                 view=LocalUsersSearchForm, manager=IToolbarViewletManager, weight=10,
                 permission=MANAGE_SECURITY_PERMISSION)
-class LocalUserAddAction(ContextAction):
+class LocalUserAddAction(ContextAddAction):
     """Local user add action"""
 
     label = _("Add user")
-    status = 'success'
-    icon_class = 'fas fa-plus'
-
     href = 'add-user.html'
-    modal_target = True
 
 
 @ajax_form_config(name='add-user.html', context=IUsersFolderPlugin, layer=IPyAMSLayer,
                   permission=MANAGE_SECURITY_PERMISSION)
-class LocalUserAddForm(AdminModalAddForm):
+class LocalUserAddForm(InnerSecurityPluginFormMixin, AdminModalAddForm):
     """Local user add form"""
 
-    @property
-    def title(self):
-        """Form title getter"""
-        return self.context.title
-
     legend = _("Add local user")
 
     fields = Fields(ILocalUser).select('login', 'email', 'firstname', 'lastname',
@@ -324,13 +316,16 @@ class ILocalUserEditFormButtons(IModalEditFormButtons):
 
 
 @ajax_form_config(name='properties.html', context=ILocalUser, layer=IPyAMSLayer)
-class LocalUserEditForm(AdminModalEditForm):
+class LocalUserEditForm(InnerSecurityPluginFormMixin, AdminModalEditForm):
     """Local user edit form"""
 
     @property
     def title(self):
         """Form title getter"""
-        return self.context.title
+        translate = self.request.localizer.translate
+        return '{}<br /><small>{}</small>'.format(
+            super().title,
+            translate(_("User: {}")).format(self.context.title))
 
     legend = _("User properties")
 
@@ -536,13 +531,16 @@ class LocalUserPermissionChecker(ContextAdapter):
 
 @ajax_form_config(name='change-password.html', context=ILocalUser, layer=IPyAMSLayer,
                   permission=MANAGE_SECURITY_PERMISSION)
-class LocalUserPasswordChangeForm(AdminModalEditForm):
+class LocalUserPasswordChangeForm(InnerSecurityPluginFormMixin, AdminModalEditForm):
     """Local user password change form"""
 
     @property
     def title(self):
         """Form title getter"""
-        return self.context.title
+        translate = self.request.localizer.translate
+        return '{}<br /><small>{}</small>'.format(
+            super().title,
+            translate(_("User: {}")).format(self.context.title))
 
     legend = _("Change user password")
 
